@@ -3,7 +3,7 @@ use 5.012;
 use warnings;
 use strict;
 
-our $VERSION = '1.51';
+our $VERSION = '1.52';
 
 use Carp;
 use Data::Compare;
@@ -202,7 +202,7 @@ sub inject {
 
     # inject_use/inject_after_sub_def are preprocs
 
-    if ($p->{inject_use} || $p->{inject_after_sub_def} || $p->{line_num}){
+    if ($p->{inject_use} || $p->{inject_after_sub_def} || defined $p->{line_num}){
         $self->{params}{pre_proc} = 'inject';
         $self->{params}{pre_proc_return} = 1;
     }
